:orphan:

.. _ug-keras_post_training_quantization_mixed_precision:


==================================================================
Keras Post Training Mixed Precision Quantization (Experimental)
==================================================================

.. autofunction:: model_compression_toolkit.keras_post_training_quantization_mixed_precision
